@@ -2,6 +2,14 @@ import os
 from backstage.venue import use_venue
 from backstage.venue import Venue
 
+class Act():
+    def __init__(self, venue, actname):
+        self.venue = venue
+        self.actname = actname
+        pass
+    pass
+
+
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
     if isinstance(venue, str):
@@ -18,4 +26,6 @@ def new_act(venue, actname):
         print 'A folder named %s already exists under %s' % (actname, acts_dir)
         return None
     os.mkdir(act_home)
+    a = Act(venue, actname)
+    return a
 
